====================================================
Korea Astronomy and Space Science Institute Open API
====================================================


.. container::

    .. image:: https://img.shields.io/pypi/v/kasi.svg
            :target: https://pypi.python.org/pypi/kasi
            :alt: PyPI Version

    .. image:: https://img.shields.io/pypi/pyversions/kasi.svg
            :target: https://pypi.python.org/pypi/kasi/
            :alt: PyPI Python Versions

    .. image:: https://img.shields.io/pypi/status/kasi.svg
            :target: https://pypi.python.org/pypi/kasi/
            :alt: PyPI Status


.. container::

    .. image:: https://img.shields.io/travis/elbakramer/kasi.svg
            :target: https://travis-ci.org/elbakramer/kasi
            :alt: Travis CI Build Status
    .. .. image:: https://travis-ci.org/elbakramer/kasi.svg?branch=master

    .. image:: https://img.shields.io/readthedocs/kasi/latest.svg
            :target: https://kasi.readthedocs.io/en/latest/?badge=latest
            :alt: ReadTheDocs Documentation Build Status
    .. .. image:: https://readthedocs.org/projects/kasi/badge/?version=latest

    .. image:: https://img.shields.io/codecov/c/github/elbakramer/kasi.svg
            :target: https://codecov.io/gh/elbakramer/kasi
            :alt: Codecov Coverage
    .. .. image:: https://codecov.io/gh/elbakramer/kasi/branch/master/graph/badge.svg

    .. image:: https://img.shields.io/requires/github/elbakramer/kasi/master.svg
            :target: https://requires.io/github/elbakramer/kasi/requirements/?branch=master
            :alt: Requires.io Requirements Status
    .. .. image:: https://requires.io/github/elbakramer/kasi/requirements.svg?branch=master


.. container::

    .. image:: https://img.shields.io/pypi/l/kasi.svg
            :target: https://github.com/elbakramer/kasi/blob/master/LICENSE
            :alt: PyPI License

    .. image:: https://app.fossa.com/api/projects/git%2Bgithub.com%2Felbakramer%2Fkasi.svg?type=shield
            :target: https://app.fossa.com/projects/git%2Bgithub.com%2Felbakramer%2Fkasi?ref=badge_shield
            :alt: FOSSA Status


KASI Open API interface implemented in Python.


* Free software: MIT license
* Documentation: https://kasi.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
